==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/NodeSystemInfoFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NodeSystemInfoFluent<A extends NodeSystemInfoFluent<A>> extends Fluent<A> {


    public String getArchitecture();
    public A withArchitecture(String architecture);
    public Boolean hasArchitecture();
    public A withNewArchitecture(StringBuilder arg1);
    public A withNewArchitecture(int[] arg1,int arg2,int arg3);
    public A withNewArchitecture(char[] arg1);
    public A withNewArchitecture(StringBuffer arg1);
    public A withNewArchitecture(byte[] arg1,int arg2);
    public A withNewArchitecture(byte[] arg1);
    public A withNewArchitecture(char[] arg1,int arg2,int arg3);
    public A withNewArchitecture(byte[] arg1,int arg2,int arg3);
    public A withNewArchitecture(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewArchitecture(String arg1);
    public String getBootID();
    public A withBootID(String bootID);
    public Boolean hasBootID();
    public A withNewBootID(StringBuilder arg1);
    public A withNewBootID(int[] arg1,int arg2,int arg3);
    public A withNewBootID(char[] arg1);
    public A withNewBootID(StringBuffer arg1);
    public A withNewBootID(byte[] arg1,int arg2);
    public A withNewBootID(byte[] arg1);
    public A withNewBootID(char[] arg1,int arg2,int arg3);
    public A withNewBootID(byte[] arg1,int arg2,int arg3);
    public A withNewBootID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBootID(String arg1);
    public String getContainerRuntimeVersion();
    public A withContainerRuntimeVersion(String containerRuntimeVersion);
    public Boolean hasContainerRuntimeVersion();
    public A withNewContainerRuntimeVersion(StringBuilder arg1);
    public A withNewContainerRuntimeVersion(int[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(char[] arg1);
    public A withNewContainerRuntimeVersion(StringBuffer arg1);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2);
    public A withNewContainerRuntimeVersion(byte[] arg1);
    public A withNewContainerRuntimeVersion(char[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContainerRuntimeVersion(String arg1);
    public String getKernelVersion();
    public A withKernelVersion(String kernelVersion);
    public Boolean hasKernelVersion();
    public A withNewKernelVersion(StringBuilder arg1);
    public A withNewKernelVersion(int[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(char[] arg1);
    public A withNewKernelVersion(StringBuffer arg1);
    public A withNewKernelVersion(byte[] arg1,int arg2);
    public A withNewKernelVersion(byte[] arg1);
    public A withNewKernelVersion(char[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKernelVersion(String arg1);
    public String getKubeProxyVersion();
    public A withKubeProxyVersion(String kubeProxyVersion);
    public Boolean hasKubeProxyVersion();
    public A withNewKubeProxyVersion(StringBuilder arg1);
    public A withNewKubeProxyVersion(int[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(char[] arg1);
    public A withNewKubeProxyVersion(StringBuffer arg1);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2);
    public A withNewKubeProxyVersion(byte[] arg1);
    public A withNewKubeProxyVersion(char[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKubeProxyVersion(String arg1);
    public String getKubeletVersion();
    public A withKubeletVersion(String kubeletVersion);
    public Boolean hasKubeletVersion();
    public A withNewKubeletVersion(StringBuilder arg1);
    public A withNewKubeletVersion(int[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(char[] arg1);
    public A withNewKubeletVersion(StringBuffer arg1);
    public A withNewKubeletVersion(byte[] arg1,int arg2);
    public A withNewKubeletVersion(byte[] arg1);
    public A withNewKubeletVersion(char[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKubeletVersion(String arg1);
    public String getMachineID();
    public A withMachineID(String machineID);
    public Boolean hasMachineID();
    public A withNewMachineID(StringBuilder arg1);
    public A withNewMachineID(int[] arg1,int arg2,int arg3);
    public A withNewMachineID(char[] arg1);
    public A withNewMachineID(StringBuffer arg1);
    public A withNewMachineID(byte[] arg1,int arg2);
    public A withNewMachineID(byte[] arg1);
    public A withNewMachineID(char[] arg1,int arg2,int arg3);
    public A withNewMachineID(byte[] arg1,int arg2,int arg3);
    public A withNewMachineID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMachineID(String arg1);
    public String getOperatingSystem();
    public A withOperatingSystem(String operatingSystem);
    public Boolean hasOperatingSystem();
    public A withNewOperatingSystem(StringBuilder arg1);
    public A withNewOperatingSystem(int[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(char[] arg1);
    public A withNewOperatingSystem(StringBuffer arg1);
    public A withNewOperatingSystem(byte[] arg1,int arg2);
    public A withNewOperatingSystem(byte[] arg1);
    public A withNewOperatingSystem(char[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(byte[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOperatingSystem(String arg1);
    public String getOsImage();
    public A withOsImage(String osImage);
    public Boolean hasOsImage();
    public A withNewOsImage(StringBuilder arg1);
    public A withNewOsImage(int[] arg1,int arg2,int arg3);
    public A withNewOsImage(char[] arg1);
    public A withNewOsImage(StringBuffer arg1);
    public A withNewOsImage(byte[] arg1,int arg2);
    public A withNewOsImage(byte[] arg1);
    public A withNewOsImage(char[] arg1,int arg2,int arg3);
    public A withNewOsImage(byte[] arg1,int arg2,int arg3);
    public A withNewOsImage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOsImage(String arg1);
    public String getSystemUUID();
    public A withSystemUUID(String systemUUID);
    public Boolean hasSystemUUID();
    public A withNewSystemUUID(StringBuilder arg1);
    public A withNewSystemUUID(int[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(char[] arg1);
    public A withNewSystemUUID(StringBuffer arg1);
    public A withNewSystemUUID(byte[] arg1,int arg2);
    public A withNewSystemUUID(byte[] arg1);
    public A withNewSystemUUID(char[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(byte[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSystemUUID(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/NodeSystemInfoFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NodeSystemInfoFluent<A extends NodeSystemInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getArchitecture();
    public A withArchitecture(String architecture);
    public Boolean hasArchitecture();
    public A withNewArchitecture(StringBuilder arg1);
    public A withNewArchitecture(int[] arg1,int arg2,int arg3);
    public A withNewArchitecture(char[] arg1);
    public A withNewArchitecture(StringBuffer arg1);
    public A withNewArchitecture(byte[] arg1,int arg2);
    public A withNewArchitecture(byte[] arg1);
    public A withNewArchitecture(char[] arg1,int arg2,int arg3);
    public A withNewArchitecture(byte[] arg1,int arg2,int arg3);
    public A withNewArchitecture(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewArchitecture(String arg1);
    public String getBootID();
    public A withBootID(String bootID);
    public Boolean hasBootID();
    public A withNewBootID(StringBuilder arg1);
    public A withNewBootID(int[] arg1,int arg2,int arg3);
    public A withNewBootID(char[] arg1);
    public A withNewBootID(StringBuffer arg1);
    public A withNewBootID(byte[] arg1,int arg2);
    public A withNewBootID(byte[] arg1);
    public A withNewBootID(char[] arg1,int arg2,int arg3);
    public A withNewBootID(byte[] arg1,int arg2,int arg3);
    public A withNewBootID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewBootID(String arg1);
    public String getContainerRuntimeVersion();
    public A withContainerRuntimeVersion(String containerRuntimeVersion);
    public Boolean hasContainerRuntimeVersion();
    public A withNewContainerRuntimeVersion(StringBuilder arg1);
    public A withNewContainerRuntimeVersion(int[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(char[] arg1);
    public A withNewContainerRuntimeVersion(StringBuffer arg1);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2);
    public A withNewContainerRuntimeVersion(byte[] arg1);
    public A withNewContainerRuntimeVersion(char[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2,int arg3);
    public A withNewContainerRuntimeVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContainerRuntimeVersion(String arg1);
    public String getKernelVersion();
    public A withKernelVersion(String kernelVersion);
    public Boolean hasKernelVersion();
    public A withNewKernelVersion(StringBuilder arg1);
    public A withNewKernelVersion(int[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(char[] arg1);
    public A withNewKernelVersion(StringBuffer arg1);
    public A withNewKernelVersion(byte[] arg1,int arg2);
    public A withNewKernelVersion(byte[] arg1);
    public A withNewKernelVersion(char[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKernelVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKernelVersion(String arg1);
    public String getKubeProxyVersion();
    public A withKubeProxyVersion(String kubeProxyVersion);
    public Boolean hasKubeProxyVersion();
    public A withNewKubeProxyVersion(StringBuilder arg1);
    public A withNewKubeProxyVersion(int[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(char[] arg1);
    public A withNewKubeProxyVersion(StringBuffer arg1);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2);
    public A withNewKubeProxyVersion(byte[] arg1);
    public A withNewKubeProxyVersion(char[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKubeProxyVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKubeProxyVersion(String arg1);
    public String getKubeletVersion();
    public A withKubeletVersion(String kubeletVersion);
    public Boolean hasKubeletVersion();
    public A withNewKubeletVersion(StringBuilder arg1);
    public A withNewKubeletVersion(int[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(char[] arg1);
    public A withNewKubeletVersion(StringBuffer arg1);
    public A withNewKubeletVersion(byte[] arg1,int arg2);
    public A withNewKubeletVersion(byte[] arg1);
    public A withNewKubeletVersion(char[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(byte[] arg1,int arg2,int arg3);
    public A withNewKubeletVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKubeletVersion(String arg1);
    public String getMachineID();
    public A withMachineID(String machineID);
    public Boolean hasMachineID();
    public A withNewMachineID(StringBuilder arg1);
    public A withNewMachineID(int[] arg1,int arg2,int arg3);
    public A withNewMachineID(char[] arg1);
    public A withNewMachineID(StringBuffer arg1);
    public A withNewMachineID(byte[] arg1,int arg2);
    public A withNewMachineID(byte[] arg1);
    public A withNewMachineID(char[] arg1,int arg2,int arg3);
    public A withNewMachineID(byte[] arg1,int arg2,int arg3);
    public A withNewMachineID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMachineID(String arg1);
    public String getOperatingSystem();
    public A withOperatingSystem(String operatingSystem);
    public Boolean hasOperatingSystem();
    public A withNewOperatingSystem(StringBuilder arg1);
    public A withNewOperatingSystem(int[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(char[] arg1);
    public A withNewOperatingSystem(StringBuffer arg1);
    public A withNewOperatingSystem(byte[] arg1,int arg2);
    public A withNewOperatingSystem(byte[] arg1);
    public A withNewOperatingSystem(char[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(byte[] arg1,int arg2,int arg3);
    public A withNewOperatingSystem(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOperatingSystem(String arg1);
    public String getOsImage();
    public A withOsImage(String osImage);
    public Boolean hasOsImage();
    public A withNewOsImage(StringBuilder arg1);
    public A withNewOsImage(int[] arg1,int arg2,int arg3);
    public A withNewOsImage(char[] arg1);
    public A withNewOsImage(StringBuffer arg1);
    public A withNewOsImage(byte[] arg1,int arg2);
    public A withNewOsImage(byte[] arg1);
    public A withNewOsImage(char[] arg1,int arg2,int arg3);
    public A withNewOsImage(byte[] arg1,int arg2,int arg3);
    public A withNewOsImage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOsImage(String arg1);
    public String getSystemUUID();
    public A withSystemUUID(String systemUUID);
    public Boolean hasSystemUUID();
    public A withNewSystemUUID(StringBuilder arg1);
    public A withNewSystemUUID(int[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(char[] arg1);
    public A withNewSystemUUID(StringBuffer arg1);
    public A withNewSystemUUID(byte[] arg1,int arg2);
    public A withNewSystemUUID(byte[] arg1);
    public A withNewSystemUUID(char[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(byte[] arg1,int arg2,int arg3);
    public A withNewSystemUUID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSystemUUID(String arg1);
}
